@@ -110,6 +110,8 @@ def save_and_compile_tex(out_dir, filename, lines, logs=False):
         print(f"- saved source as {complete_source_out_dir / filename}.tex")
 
     temp_dir = complete_out_dir / "tmp"
+    if not temp_dir.is_dir():
+        Path.mkdir(temp_dir, parents=True)
 
     run_args = ['pdflatex', f"-output-directory={temp_dir}", "-jobname=file"]
     
